package com.asiainfo.c3.http.service.mvc;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.asiainfo.c3.http.service.model.popup.request.AbstractRequestBean;
import com.asiainfo.c3.http.service.model.popup.request.impl.CustPopupWindowRequest;
import com.asiainfo.c3.http.service.model.popup.request.impl.SMSHallPopupWindowRequest;
import com.asiainfo.c3.http.service.model.popup.request.impl.UserPopupWindowRequest;
import com.asiainfo.c3.http.service.model.popup.response.AbstractPopupWindowResponse;
import com.asiainfo.c3.http.service.model.popup.response.impl.CostTimeBean;
import com.asiainfo.c3.http.service.model.popup.response.impl.CustPopupWindowResponse;
import com.asiainfo.c3.http.service.model.popup.response.impl.UserPopupWindowResponse;
import com.asiainfo.c3.http.service.service.impl.PopupWindowService;
import com.asiainfo.c3.http.service.service.impl.SMSHallPopupWindowServciceImpl;
import com.asiainfo.c3.util.Config;
import com.asiainfo.c3.util.http.HttpClientUtils;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

@RequestMapping({"/"})
@Controller
/* loaded from: ExecOrderController.class */
public class ExecOrderController extends DataControlController {
    private static final Logger log = LoggerFactory.getLogger(ExecOrderController.class);

    @RequestMapping(value = {"ExtExecOrderUCServlet"}, produces = {"application/json; charset=utf-8"}, method = {RequestMethod.POST})
    @ResponseBody
    public String extExecOrderUCServlet(@RequestBody String request) {
        return execOrderUCServlet(request);
    }

    @RequestMapping(value = {"ExecOrderUCServlet"}, produces = {"application/json; charset=utf-8"}, method = {RequestMethod.POST})
    @ResponseBody
    public String execOrderUCServlet(@RequestBody String request) {
        long startTime = System.currentTimeMillis();
        CostTimeBean costTimeBean = new CostTimeBean();
        costTimeBean.setStartTime(startTime);
        try {
            log.info("收到用户弹窗请求:{}", request);
            UserPopupWindowRequest userPopupWindowRequest = (UserPopupWindowRequest) JSON.toJavaObject(JSONObject.parseObject(request), UserPopupWindowRequest.class);
            UserPopupWindowResponse checkUCRequestParams = PopupWindowService.checkUCRequestParams(userPopupWindowRequest);
            if (null != checkUCRequestParams) {
                return ((JSONObject) JSONObject.toJSON(checkUCRequestParams)).toJSONString();
            }
            AbstractPopupWindowResponse response = PopupWindowService.getResponse(userPopupWindowRequest, costTimeBean);
            JSONObject responseJson = (JSONObject) JSONObject.toJSON(response);
            costTimeBean.setEndTime(System.currentTimeMillis());
            log.info("返回用户弹窗报文: {}", responseJson);
            log.info("用户:{}弹窗花费时长:{}, 开始时间: {}, 结束时间： {}", new Object[]{userPopupWindowRequest.getRequest().getObjectId(), Long.valueOf(costTimeBean.getEndTime() - costTimeBean.getStartTime()), Long.valueOf(costTimeBean.getStartTime()), Long.valueOf(costTimeBean.getEndTime())});
            return responseJson.toJSONString();
        } catch (Exception e) {
            String objectId = "";
            if (null != request) {
                objectId = StringUtils.substringBetween(request, "objectId\": \"", "\"");
            }
            String objectId2 = null == objectId ? "" : objectId;
            log.error("{}弹窗异常: {}", objectId2, e);
            return ((JSONObject) JSONObject.toJSON(new UserPopupWindowResponse(objectId2, 0, "弹窗异常!"))).toJSONString();
        }
    }

    @RequestMapping(value = {"ExecOrderCustServlet"}, produces = {"application/json; charset=utf-8"}, method = {RequestMethod.POST})
    @ResponseBody
    public String execOrderCustServlet(@RequestBody String request) {
        long startTime = System.currentTimeMillis();
        CostTimeBean costTimeBean = new CostTimeBean();
        costTimeBean.setStartTime(startTime);
        try {
            log.info("收到客户弹窗请求:{}", request);
            CustPopupWindowRequest custPopupWindowRequest = (CustPopupWindowRequest) JSON.toJavaObject(JSONObject.parseObject(request), CustPopupWindowRequest.class);
            CustPopupWindowResponse checkCustRequestParams = PopupWindowService.checkCustRequestParams(custPopupWindowRequest);
            if (null != checkCustRequestParams) {
                return ((JSONObject) JSONObject.toJSON(checkCustRequestParams)).toJSONString();
            }
            AbstractPopupWindowResponse response = PopupWindowService.getResponse(custPopupWindowRequest, costTimeBean);
            JSONObject responseJson = (JSONObject) JSONObject.toJSON(response);
            costTimeBean.setEndTime(System.currentTimeMillis());
            log.info("返回客户弹窗报文: {}", responseJson);
            log.info("客户:{}弹窗花费时长:{}, 开始时间: {}, 结束时间： {}", new Object[]{custPopupWindowRequest.getRequest().getObjectId(), Long.valueOf(costTimeBean.getEndTime() - costTimeBean.getStartTime()), Long.valueOf(costTimeBean.getStartTime()), Long.valueOf(costTimeBean.getEndTime())});
            return responseJson.toJSONString();
        } catch (Exception e) {
            String objectId = "";
            if (null != request) {
                objectId = StringUtils.substringBetween(request, "objectId\": \"", "\"");
            }
            String objectId2 = null == objectId ? "" : objectId;
            log.error("{}弹窗异常: {}", objectId2, e);
            return ((JSONObject) JSONObject.toJSON(new CustPopupWindowResponse(objectId2, 0, "弹窗异常!"))).toJSONString();
        }
    }

    @RequestMapping(value = {"ExecOrderViewServlet"}, produces = {"application/json; charset=utf-8"}, method = {RequestMethod.POST})
    @ResponseBody
    public String execOrderViewServlet(@RequestBody UserPopupWindowRequest popupWindowRequest) {
        CostTimeBean costTimeBean = new CostTimeBean();
        costTimeBean.setStartTime(System.currentTimeMillis());
        try {
            log.info("收到弹窗请求: {}", JSONObject.toJSONString(popupWindowRequest));
            UserPopupWindowResponse checkUCRequestParams = PopupWindowService.checkUCRequestParams(popupWindowRequest);
            if (null != checkUCRequestParams) {
                JSONObject responseJson = (JSONObject) JSONObject.toJSON(checkUCRequestParams);
                return responseJson.toJSONString();
            }
            if (StringUtils.isBlank(Config.getObject("offer_view_url"))) {
                JSONObject responseJson2 = (JSONObject) JSONObject.toJSON(new CustPopupWindowResponse("", 0, "根据号码查融合下号码接口未配置!"));
                return responseJson2.toJSONString();
            }
            String objectId = popupWindowRequest.getRequest().getObjectId();
            JSONObject viewParam = new JSONObject();
            if (StringUtils.isNotBlank(Config.getObject("custId_view_url"))) {
                String[] objectIds = objectId.split(",");
                JSONArray instReq = new JSONArray();
                for (String object_ : objectIds) {
                    JSONObject objReq = new JSONObject();
                    objReq.put("accNum", object_);
                    instReq.add(objReq);
                }
                log.info("查询custId接口请求: {}", instReq.toJSONString());
                long startTime = System.currentTimeMillis();
                JSONObject custResponse = HttpClientUtils.sendHttpPost(Config.getObject("custId_view_url"), instReq.toJSONString());
                log.info("根据号码调crm接口查询custId耗时: {} ms", Long.valueOf(System.currentTimeMillis() - startTime));
                log.info("查询custId接口响应: {}", custResponse);
                if (null != custResponse && null != custResponse.getJSONObject("result") && "0".equals(custResponse.getJSONObject("result").getString("resultCode")) && null != custResponse.getJSONObject("result").getJSONObject("resultObject") && null != custResponse.getJSONObject("result").getJSONObject("resultObject").getJSONArray("accProdInsts") && custResponse.getJSONObject("result").getJSONObject("resultObject").getJSONArray("accProdInsts").size() > 0) {
                    JSONArray accProdInsts = custResponse.getJSONObject("result").getJSONObject("resultObject").getJSONArray("accProdInsts");
                    String custIds = "";
                    for (int i = 0; i < accProdInsts.size(); i++) {
                        String ownerCustId = accProdInsts.getJSONObject(i).getString("ownerCustId");
                        if (StringUtils.isNotBlank(ownerCustId)) {
                            custIds = custIds + ownerCustId + ",";
                        }
                    }
                    if (StringUtils.isNotBlank(custIds)) {
                        viewParam.put("custId", custIds.substring(0, custIds.length() - 1));
                    }
                }
            }
            JSONObject viewReq = new JSONObject();
            viewParam.put("accNum", objectId);
            viewReq.put("requestObject", viewParam);
            log.info("查询已订购视图信息请求: {}", viewReq);
            long startTime2 = System.currentTimeMillis();
            JSONObject viewResponse = HttpClientUtils.sendHttpPost(Config.getObject("offer_view_url"), viewReq);
            log.info("根据号码+custid查询crm接口查询融合套餐下的所有号码耗时: {} ms", Long.valueOf(System.currentTimeMillis() - startTime2));
            log.info("查询已订购视图信息响应: {}", viewResponse);
            if (null == viewResponse || null == viewResponse.getJSONObject("result") || !"0".equals(viewResponse.getJSONObject("result").getString("resultCode")) || null == viewResponse.getJSONObject("result").getJSONObject("resultObject") || null == viewResponse.getJSONObject("result").getJSONObject("resultObject").getJSONArray("offerInsts") || viewResponse.getJSONObject("result").getJSONObject("resultObject").getJSONArray("offerInsts").size() < 1) {
                JSONObject responseJson3 = (JSONObject) JSONObject.toJSON(new CustPopupWindowResponse("", 0, "返回报文未找到offerInsts字段!"));
                return responseJson3.toJSONString();
            }
            JSONArray offerInsts = viewResponse.getJSONObject("result").getJSONObject("resultObject").getJSONArray("offerInsts");
            String accNums = "";
            for (int i2 = 0; i2 < offerInsts.size(); i2++) {
                JSONArray prodInsts = offerInsts.getJSONObject(i2).getJSONArray("prodInsts");
                if (null != prodInsts && prodInsts.size() > 0) {
                    for (int j = 0; j < prodInsts.size(); j++) {
                        if (StringUtils.isNotBlank(prodInsts.getJSONObject(j).getString("accNum")) && "101".equals(prodInsts.getJSONObject(j).getString("prodFuncType"))) {
                            accNums = accNums + prodInsts.getJSONObject(j).getString("accNum") + ",";
                        }
                    }
                }
            }
            if (StringUtils.isBlank(accNums)) {
                JSONObject responseJson4 = (JSONObject) JSONObject.toJSON(new CustPopupWindowResponse("", 0, "返回报文未找到accNum字段!"));
                return responseJson4.toJSONString();
            }
            AbstractRequestBean request = popupWindowRequest.getRequest();
            request.setObjectId(accNums.substring(0, accNums.length() - 1));
            popupWindowRequest.setRequest(request);
            log.info("hbase弹窗请求: {}", JSONObject.toJSONString(popupWindowRequest));
            AbstractPopupWindowResponse response = PopupWindowService.getResponse(popupWindowRequest, costTimeBean);
            JSONObject responseJson5 = (JSONObject) JSONObject.toJSON(response);
            return responseJson5.toJSONString();
        } catch (Exception e) {
            String objectId2 = "";
            if (null != popupWindowRequest.getRequest()) {
                objectId2 = popupWindowRequest.getRequest().getObjectId();
            }
            String objectId3 = null == objectId2 ? "" : objectId2;
            log.error("{}弹窗异常: {}", objectId3, e);
            JSONObject responseJson6 = (JSONObject) JSONObject.toJSON(new CustPopupWindowResponse(objectId3, 0, "弹窗异常!"));
            return responseJson6.toJSONString();
        }
    }

    @RequestMapping(value = {"SMSHallQueryServlet"}, produces = {"application/json; charset=utf-8"}, method = {RequestMethod.POST})
    @ResponseBody
    public String SMSHallQueryServlet(@RequestBody SMSHallPopupWindowRequest smsHallRequestBean) {
        CostTimeBean costTimeBean = new CostTimeBean();
        costTimeBean.setStartTime(System.currentTimeMillis());
        try {
            log.info("收到弹窗请求: {}", JSONObject.toJSONString(smsHallRequestBean));
            UserPopupWindowResponse checkRequestParams = SMSHallPopupWindowServciceImpl.checkRequestParams(smsHallRequestBean);
            if (null != checkRequestParams) {
                JSONObject responseJson = (JSONObject) JSONObject.toJSON(checkRequestParams);
                return responseJson.toJSONString();
            }
            AbstractPopupWindowResponse response = SMSHallPopupWindowServciceImpl.getResponse(smsHallRequestBean, costTimeBean);
            JSONObject responseJson2 = (JSONObject) JSONObject.toJSON(response);
            return responseJson2.toJSONString();
        } catch (Exception e) {
            String objectId = null == smsHallRequestBean.getRequest().getObjectId() ? "" : "";
            log.error("{}弹窗异常: {}", objectId, e);
            JSONObject responseJson3 = (JSONObject) JSONObject.toJSON(new UserPopupWindowResponse(objectId, 0, "弹窗异常!"));
            return responseJson3.toJSONString();
        }
    }

    @RequestMapping(value = {"ExecOrderSP"}, produces = {"application/json; charset=utf-8"}, method = {RequestMethod.POST})
    @ResponseBody
    public String execOrderSP(@RequestBody String request, HttpServletResponse response) {
        JSONObject responseJson = new JSONObject();
        JSONObject reqJson = JSONObject.parseObject(request);
        List<String> requiredFields = Arrays.asList("objectId", "contactChlId", "contactOrderId");
        for (String field : requiredFields) {
            if (StringUtils.isBlank(reqJson.getString(field))) {
                responseJson.put("resultCode", 0);
                responseJson.put("resultDesc", "请求失败，" + field + "等必要参数不能为空");
                return responseJson.toJSONString();
            }
        }
        try {
            responseJson = PopupWindowService.getStrActResponse(reqJson);
        } catch (Exception e) {
            log.error("请求接口失败", e);
            responseJson.put("resultCode", 0);
            responseJson.put("resultDesc", "请求失败，" + e.getMessage());
        }
        response.setHeader("Connection", "close");
        return responseJson.toJSONString();
    }
}
